package org.ferris.dyndns.jmce.jobs;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang.exception.ExceptionUtils;
import org.apache.http.auth.AuthScope;
import org.apache.http.client.params.CookiePolicy;
import org.apache.log4j.Logger;
import org.ferris.dyndns.jmce.mail.SimpleMailMessage;
import org.ferris.dyndns.jmce.util.PropertiesFactory;
import org.ferris.net.runner.HttpsRequestRunner;
import org.quartz.Job;
import org.quartz.JobExecutionContext;
import org.quartz.JobExecutionException;

public class DyndnsJob implements Job
{
	private final Logger log = Logger.getLogger(getClass());
	private List<String> errors;
	
	
	public DyndnsJob() {
		errors = new ArrayList<String>();
	}
	
	public List<String> getErrors() {
		return errors;
	}
	
	public void execute(JobExecutionContext arg0) throws JobExecutionException 
	{				
		log.info("DyndnsJob executing()");
		errors.clear();
		
		try {
					
			AuthScope as
				= new AuthScope("www.dyndns.com", -1);
			
			HttpsRequestRunner<String> runner
				= new HttpsRequestRunner<String>(as);		
            runner.setCookiePolicy(CookiePolicy.BEST_MATCH);
			
			//
			// GO TO LOGIN PAGE
			//
			String multiform
			    = runner.get("/account/entrance/", new DyndnsHttpResponseHandlerForHomepage()).get(0);
			log.info("multiform=" + multiform);
		
			// 
			// ATTEMPT LOGIN
			//
            /*
            <form id='login70' action='/account/entrance/' class='basic' method='post'>
                <fieldset>
                    <div class='legend'>Already Registered?</div>
                    <label for='login70_username'>Username</label>
                    <fieldset>
                        <input id='login70_username' name='username'/></fieldset>
                    <label for='login70_password'>Password</label>
                    <fieldset>
                        <input id='login70_password' name='password' type='password' value='' autocomplete='off'/></fieldset></fieldset>
                    <fieldset class='submit'>
                        <input type='submit' name='submit' id='login70_submit' value='Log in'/></fieldset>
                    <div class='someinfo'><a href='/account/resetpass/'>Forgot your password?</a></div>
                        <input type='hidden' name='multiform' value='912F50EAA8F1D51D840054E28AE57B7981'/>
            </form>
             */

			//username
			runner.addParameter(PropertiesFactory.getUsername());
			//password
			runner.addParameter(PropertiesFactory.getPassword());
			//submit
			runner.addParameter("Log in");
			//multiform
			runner.addParameter(multiform);
			
			String page
			    = runner.post("/account/entrance/?username=?&password=?&submit=?&multiform=?", new DyndnsHttpResponseHandler()).get(0);
			
			log.debug("PAGE");
			log.debug(page);
			
			String contains
				// = "<title>dyndns -- my account</title>".toLowerCase();	
				//= "Logged In User: <b>mjremijan</b>".toLowerCase();
				= "Welcome&nbsp;<b>mjremijan</b>".toLowerCase()
            ;
			    			
			if (! page.toLowerCase().contains(contains)) {
				errors.add("Missing Phrase: "+html(contains));
				errors.add("HTML Source:" + html(page));
			}			
		}
		catch (RuntimeException e) {
			errors.add(ExceptionUtils.getFullStackTrace(e));
		}
		
		if (errors.size() == 0) {
			log.info("No errors found.");
		} 
		else {
			email();
		}
	}
	
	private String html(String html) {
		return "<pre>"
			+ html.replaceAll("<", "&lt;").replaceAll(">", "&gt;")
			+ "</pre>";
	}
	
	public void email() 
	{
		String isMailEnabled
			= System.getProperty("org.ferris.dyndns.jmce.mail.isMailEnabled", "true");
		if (isMailEnabled.toLowerCase().charAt(0) == 'f') {
			log.info(
				String.format(
					"Property org.ferris.dyndns.jmce.mail.isMailEnabled=\"%s\" so skipping e-mail!"
					, isMailEnabled
				)
			);
			return;
		} 
		
		log.info("Errors found, e-mailing...");
		
		try {
			
			SimpleMailMessage smm = new SimpleMailMessage(PropertiesFactory.getHost());

			smm.addTo(PropertiesFactory.getToAddress()[0], PropertiesFactory.getToAddress()[1]);

			smm.setFrom(PropertiesFactory.getFromAddress()[0], PropertiesFactory.getFromAddress()[1]);
			
			smm.setSubject(PropertiesFactory.getSubject());
		  
			String html = "";
			html += "<html>";
			html += "<table border='1'>";
			int x = 0;
			for (String error : errors) {
				html += "<tr>";
					html += "<td>";
						html += ++x;
					html += "</td>";	
					html += "<td>";
						html += error;
					html += "</td>";
				html += "</tr>";
			}			  
			html += "</table>";
			html += "</html>";
		  
			smm.setText(html);
		
			smm.sendAsHtml();
		}
		catch (Throwable e) {
			log.fatal(e.getMessage(),e);
		}
	}
	
}
