package org.ferris.dyndns.jmce.mail;

import java.util.Date;
import java.util.Properties;

import javax.activation.DataHandler;
import javax.mail.Address;
import javax.mail.Message;
import javax.mail.Session;
import javax.mail.Transport;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeMessage;


@SuppressWarnings("restriction")
public class SimpleMailMessage
{
    private Session             m_sendMailSession;
    private MimeMessage         m_message;
    private String              body;

    /**
     * Class constructor.
     *
     * @exception Excpetion
     *  Throws an exception if the mail.properties
     * file that specifies the SMTP server cannot be found or read.
     */
    public SimpleMailMessage(String smtpServer)
    throws Exception
    {
        Properties props = new Properties();
        props.put("mail.smtp.host", smtpServer);
        m_sendMailSession = Session.getInstance(props, null);
        m_message = new MimeMessage(m_sendMailSession);
    }

    public void setFrom(String in_address, String in_name)
    throws Exception
    {
        m_message.setFrom(new InternetAddress(in_address, in_name));
    }




    public void setReplyTo(String in_address)
    throws Exception
    {
        m_message.setReplyTo(new Address [] {new InternetAddress(in_address)});
    }




    public void addTo(String in_address, String in_name)
    throws Exception
    {
        m_message.addRecipient(
        		Message.RecipientType.TO, new InternetAddress(in_address,in_name)
        		);
    }




    public void addCC(String in_address)
    throws Exception
    {
        m_message.addRecipient(Message.RecipientType.CC, new InternetAddress(in_address));
    }




    public void addBCC(String in_address)
    throws Exception
    {
        m_message.addRecipient(Message.RecipientType.BCC, new InternetAddress(in_address));
    }




    public void setSubject(String in_subject)
    throws Exception
    {
        m_message.setSubject(in_subject);
    }




    public void setText(String in_text)
    throws Exception
    {
        body = in_text;
    }




    public MimeMessage getMimeMessage()
    {
        return m_message;
    }




    public void sendAsText()
    throws Exception
    {
        this.send(false);
    }




    public void sendAsHtml()
    throws Exception
    {
        this.send(true);
    }



    private void send(boolean asHtml)
    throws Exception
    {
        m_message.setSentDate(new Date());
        if (asHtml)
        {
            m_message.setHeader("X-Mailer", "sendhtml");
            m_message.setDataHandler(new DataHandler(new ByteArrayDataSource(body, "text/html")));
        }
        else
        {
            m_message.setText(body);
        }
        //Transport transport;
        //transport = m_sendMailSession.getTransport("smtp");
        Transport.send(m_message);
    }



    /**
     * Quick Test
     */
    public static final void main(String [] args)
    throws Exception
    {
      //  SimpleMailMessage smm = new SimpleMailMessage();
        //System.out.println("SMTP Server = " + smm.getSMTPServer());
    }

}