package org.ferris.dyndns.jmce.util;

import java.io.InputStream;
import java.util.Properties;

import org.apache.commons.io.IOUtils;

public class PropertiesFactory
{
	private static String privatePropertiesPath
		= "/ferris-dyndns-jmce-private.properties";
	
	private static Properties privateProperties;
	
	/**
	 * Get private properties
	 */
	private static Properties getPrivateProperties()
	{
		if (privateProperties == null)
		{
			InputStream is = null;
			try {
				is = PropertiesFactory.class.getResourceAsStream(privatePropertiesPath);
				if (is == null) {
					throw new RuntimeException("Properties file \""+privatePropertiesPath+"\" not found.");
				}
				privateProperties = new Properties();
				privateProperties.load(is);
			} catch (RuntimeException e) {
				// do nothing
			} catch (Throwable t) {
				throw new RuntimeException(t.getMessage(),t);
			} finally {
				IOUtils.closeQuietly(is);
			}
		}
		return privateProperties;
	}
	
	/**
	 * Hostname of the e-mail server, usually something like mail.company.com
	 * host=
	 */
	public static String getHost() {
		return getPrivateProperties().getProperty("host");
	}
	
	/**
	 * # E-Mail address of the person to send the email to.
	 * to_address=
	 * # The name of the person to send the email to.
	 * to_name=
	 */
	public static String[] getToAddress() {
		return new String[]{
			 getPrivateProperties().getProperty("to_address")
			,getPrivateProperties().getProperty("to_name")
		};
	}
	
	/**
	 * # E-Mail address of the person the email is from.
	 * from_address=
	 * # The name of the person the email is from.
	 * from_name=
	 */
	public static String[] getFromAddress() {
		return new String[]{
			 getPrivateProperties().getProperty("from_address")
			,getPrivateProperties().getProperty("from_name")
		};
	}
	
	/**
	 * # The subject for the E-Mail message
	 * subject=
	 */
	public static String getSubject() {
		return getPrivateProperties().getProperty("subject");
	}	
	
	/**
	 * # Dyndns username login
	 * username=
	 */
	public static String getUsername() {
		return getPrivateProperties().getProperty("username");
	}
	
	/**
	 * # Dyndns username password
	 * password=
	 */
	public static String getPassword() {
		return getPrivateProperties().getProperty("password");
	}

    public static void setProperties(Properties properties) {
        privateProperties = properties;
    }
}
